@@ -1,14 +1,16 @@
 from smtplib import SMTP as PySMTP
 from socket import socket
 
-from OpenSSL import SSL, _util
-
 from sslscan import modules
 from sslscan.module.handler.tcp import TCP
 
 
 class SMTP(TCP):
-    name="smtp"
+    """
+    Handle SMTP-connections.
+    """
+
+    name = "smtp"
 
     config_options = TCP.config_options + [
         (
@@ -19,6 +21,7 @@ class SMTP(TCP):
             }
         )
     ]
+
     def __init__(self, **kwargs):
         self.port = 25
         TCP.__init__(self, **kwargs)
