@@ -1,13 +1,15 @@
 from socket import socket
 
-from OpenSSL import SSL, _util
-
 from sslscan import modules
 from sslscan.module.handler import BaseHandler
 
 
 class TCP(BaseHandler):
-    name="tcp"
+    """
+    Handle raw TCP-connections.
+    """
+
+    name = "tcp"
 
     def __init__(self, **kwargs):
         self.port = 443
