@@ -6,15 +6,21 @@ from sslscan.module.scan import BaseScan
 
 
 class ClientCiphers(BaseScan):
-    name="client.ciphers"
+    """
+    List all client ciphers.
+
+    This module lists all ciphers available on the client.
+    """
+
+    name = "client.ciphers"
 
     def __init__(self, **kwargs):
         BaseScan.__init__(self, **kwargs)
 
     def run(self):
-        kb = self.scanner.get_knowledge_base()
+        kb = self._scanner.get_knowledge_base()
 
-        for method in self.scanner.get_enabled_methods():
+        for method in self._scanner.get_enabled_methods():
             try:
                 ctx = SSL.Context(method)
             except:
