@@ -1,5 +1,3 @@
-from socket import socket
-
 from OpenSSL import SSL, _util
 
 from sslscan import modules
@@ -8,15 +6,19 @@ from sslscan.module.scan import BaseScan
 
 
 class ServerPreferredCiphers(BaseScan):
+    """
+    Detect preferred server ciphers.
+    """
+
     name="server.preferred_ciphers"
 
     def __init__(self, **kwargs):
         BaseScan.__init__(self, **kwargs)
 
     def run(self):
-        kb = self.scanner.get_knowledge_base()
+        kb = self._scanner.get_knowledge_base()
 
-        for method in self.scanner.get_enabled_methods():
+        for method in self._scanner.get_enabled_methods():
             try:
                 ctx = SSL.Context(method)
             except:
@@ -24,7 +26,7 @@ class ServerPreferredCiphers(BaseScan):
                 continue
 
             ctx.set_cipher_list("ALL:COMPLEMENT")
-            conn = self.scanner.handler.connect()
+            conn = self._scanner.handler.connect()
             conn_ssl = SSL.Connection(ctx, conn)
             conn_ssl.set_connect_state()
 
@@ -47,7 +49,6 @@ class ServerPreferredCiphers(BaseScan):
 
             kb.append("server.preferred_ciphers", cipher)
 
-
             conn_ssl.close()
 
 
